/******************************************************************************
;  *       @型号                 : MC51F003A4
;  *       @创建日期             : 2022.12.19
;  *       @公司/作者            : SINOMCU.COM-AE
;  *       @晟矽微官网           : http://www.sinomcu.com/
;  *       @版权                 : 晟矽微电 版权所有.
;  *----------------------摘要描述---------------------------------
;  * Timer设置宏定义                                                      
******************************************************************************/

#ifndef TIMER_H__
#define TIMER_H__

#include "MC51F003A4_COMMON.h"

#define  TIME0_CLK_DIV_POS   0x0
#define  TIME0_CLK_DIV_MASK  (0x3 <<TIME0_CLK_DIV_POS)
#define  TIME0_CLK_DIV_1     (0x0 <<TIME0_CLK_DIV_POS)
#define  TIME0_CLK_DIV_2     (0x1 <<TIME0_CLK_DIV_POS)
#define  TIME0_CLK_DIV_8     (0x2 <<TIME0_CLK_DIV_POS)
#define  TIME0_CLK_DIV_16    (0x3 <<TIME0_CLK_DIV_POS)

#define  Time0_16Bit()                 TMOD &= ~0x03;TMOD |= 0x01
#define  Time0_ClkFsys()               TCON1 &= ~0x08
#define  Timer0_Stop()                 TR0  = 0
#define  Timer0_Start()                TR0  = 1
#define  Timer0_Interrupt_Enable()     T0IE = 1
#define  Timer0_Interrupt_Disable()    T0IE = 0
#define  Timer0_Clear_TF()             TF0  = 0
#define  Get_Timer0_TF()               TF0?SET:RESET 
#define  Timer0_IE_En()                T0IE = 1

#define TIMER1_MODE_POS           0x04
#define TIMER1_MODE_MASK          (0x03 << TIMER1_MODE_POS)
#define TIMER1_MODE_13BIT         (0x00 << TIMER1_MODE_POS)
#define TIMER1_MODE_16BIT         (0x01 << TIMER1_MODE_POS)
#define TIMER1_MODE_8BIT_RELOAD   (0x02 << TIMER1_MODE_POS)
#define TIMER1_MODE_DISABLE       (0x03 << TIMER1_MODE_POS)
#define Timer1_Mode_Set(Timer_mode) { TMOD &= ~TIMER1_MODE_MASK; TMOD |= Timer_mode;}
#define Timer1_En()               TR1 = 1

#define T2_BAUD_POS               0x05
#define T2_BAUD_MASK              (0x01 << T2_BAUD_POS)
#define T2_BAUD_EN                (0x01 << T2_BAUD_POS)
#define T2_Baud_En()              T2CON1 |=T2_BAUD_EN 
#define T2_PRE_SCALE_POS          0x04
#define T2_PRE_SCALE_MASK         (0x07 << T2_PRE_SCALE_POS)
#define T2_PRE_SCALE_1            (0x00 << T2_PRE_SCALE_POS)
#define T2_PRE_SCALE_4            (0x01 << T2_PRE_SCALE_POS)
#define T2_PRE_SCALE_16           (0x02 << T2_PRE_SCALE_POS)
#define T2_PRE_SCALE_32           (0x03 << T2_PRE_SCALE_POS)
#define T2_PRE_SCALE_64           (0x04 << T2_PRE_SCALE_POS)
#define T2_PRE_SCALE_128          (0x05 << T2_PRE_SCALE_POS)
#define T2_PRE_SCALE_256          (0x06 << T2_PRE_SCALE_POS)
#define T2_PRE_SCALE_512          (0x07 << T2_PRE_SCALE_POS)
#define T2_Pre_Scale(pre_scale)   {T2MOD &= ~T2_PRE_SCALE_MASK;   T2MOD |= pre_scale;}
#define Timer2_En()               TR2 = 1 

typedef enum {
  SF_TIMER_STOP = 0U,
  SF_TIMER_RUN,
  SF_TIMER_OV
} SoftTimerStatus;

void TIM0_Init(uint16_t timer_HZ);
void Start_10MS_SF_Timer(void);
void Stop_10MS_SF_Timer(void);
SoftTimerStatus Get_State_10MS_SF_Timer(void);
void Start_100MS_SF_Timer(void);
void Stop_100MS_SF_Timer(void);
SoftTimerStatus Get_State_100MS_SF_Timer(void);
void Start_User_MS_SF_Timer(uint16_t delay_ms);
void Stop_User_MS_SF_Timer(void);
SoftTimerStatus Get_State_User_MS_SF_Timer(void);

#endif

/**************************** end of file *********************************************/

